/**
 * SECTION:Preferences
 * @short_description: The base class for all preferences in the system. Preferences are serialized to files. The file is watched for changes and loads new values if the backing file changed. When any public property of a sub-class is changed, the public properties are serialized to the backing file.
 */
/**
 * PLANK_SERVICES_TYPE_PREFERENCES:
 * 
 * The type for <link linkend="PlankServicesPreferences"><type>PlankServicesPreferences</type></link>.
 */
/**
 * plank_services_preferences_verify:
 * @self: the <link linkend="PlankServicesPreferences"><type>PlankServicesPreferences</type></link> instance
 * @prop: (in): &nbsp;.  the name of the property that needs verified 
 * 
 * This method will verify the value of a property. If the value is wrong, this method should replace it with a sanitized value.
 */
/**
 * plank_services_preferences_reset_properties:
 * @self: the <link linkend="PlankServicesPreferences"><type>PlankServicesPreferences</type></link> instance
 * 
 * Resets all properties to their default values. Called from construct and before loading from the backing file.
 */
/**
 * plank_services_preferences_init_from_file:
 * @self: the <link linkend="PlankServicesPreferences"><type>PlankServicesPreferences</type></link> instance
 * @file: (in): &nbsp;.  the <link linkend="GFile"><type>GFile</type></link> of the backing file for this preferences 
 * 
 * Initializes this preferences with a backing file.
 */
/**
 * plank_services_preferences_init_from_filename:
 * @self: the <link linkend="PlankServicesPreferences"><type>PlankServicesPreferences</type></link> instance
 * @filename: (in): &nbsp;.  of the backing file for this preferences 
 * 
 * Initializes this preferences with a backing filename.
 */
/**
 * plank_services_preferences_delay:
 * @self: the <link linkend="PlankServicesPreferences"><type>PlankServicesPreferences</type></link> instance
 * 
 * Delays saving changes to the backing file until apply() is called.
 */
/**
 * plank_services_preferences_apply:
 * @self: the <link linkend="PlankServicesPreferences"><type>PlankServicesPreferences</type></link> instance
 * 
 * If any settings were changed, apply them now.
 */
/**
 * plank_services_preferences_get_filename:
 * @self: the <link linkend="PlankServicesPreferences"><type>PlankServicesPreferences</type></link> instance
 * 
 * Returns the filename of the backing file.
 * 
 * Returns: the filename of the backing file 
 */
/**
 * plank_services_preferences_delete:
 * @self: the <link linkend="PlankServicesPreferences"><type>PlankServicesPreferences</type></link> instance
 * 
 * This forces the deletion of the backing file for this preferences.
 */
/**
 * PlankServicesPreferences::deleted:
 * @preferences: the <link linkend="PlankServicesPreferences"><type>PlankServicesPreferences</type></link> instance that received the signal
 * 
 * This signal indicates that the backing file for this preferences was deleted.
 */
/**
 * PlankServicesPreferences:
 * 
 * The base class for all preferences in the system. Preferences are serialized to files. The file is watched for changes and loads new values if the backing file changed. When any public property of a sub-class is changed, the public properties are serialized to the backing file.
 */
/**
 * PlankServicesPreferencesClass:
 * @verify: virtual method used internally
 * @reset_properties: virtual method used internally
 * @parent_class: the parent class structure
 * 
 * The class structure for <link linkend="PLANK-SERVICES-TYPE-PREFERENCES:CAPS"><literal>PLANK_SERVICES_TYPE_PREFERENCES</literal></link>. All the fields in this structure are private and should never be accessed directly.
 */
/**
 * plank_services_prefs_serializable_prefs_serialize:
 * @self: the <link linkend="PlankServicesPrefsSerializable"><type>PlankServicesPrefsSerializable</type></link> instance
 * 
 * Serializes the object into a string representation.
 * 
 * Returns: the string representation of the object 
 */
/**
 * plank_services_prefs_serializable_prefs_deserialize:
 * @self: the <link linkend="PlankServicesPrefsSerializable"><type>PlankServicesPrefsSerializable</type></link> instance
 * @s: (in): &nbsp;.  the string representation of the object 
 * 
 * De-serializes the object from a string representation.
 */
/**
 * PlankServicesPrefsSerializable:
 * 
 * This interface is used by objects that need to be serialized in a Preferences. The object must have a string representation and provide these methods to translate between the string and object representations.
 */
/**
 * PlankServicesPrefsSerializableIface:
 * @prefs_serialize: virtual method called by <link linkend="plank-services-prefs-serializable-prefs-serialize"><function>plank_services_prefs_serializable_prefs_serialize()</function></link>
 * @prefs_deserialize: virtual method called by <link linkend="plank-services-prefs-serializable-prefs-deserialize"><function>plank_services_prefs_serializable_prefs_deserialize()</function></link>
 * @parent_iface: the parent interface structure
 * 
 * Interface for creating <link linkend="PlankServicesPrefsSerializable"><type>PlankServicesPrefsSerializable</type></link> implementations.
 */
